==> apache-geode-1.12.5-src.tgz: apache-geode-1.12.5-src/geode-core/src/test/java/org/apache/geode/internal/cache/wan/serial/ConcurrentSerialGatewaySenderEventProcessorJUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.wan.serial;

import static org.junit.Assert.assertEquals;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.junit.Before;
import org.junit.Test;

import org.apache.geode.internal.cache.RegionQueue;
import org.apache.geode.internal.cache.wan.AbstractGatewaySender;

public class ConcurrentSerialGatewaySenderEventProcessorJUnitTest {

  private ConcurrentSerialGatewaySenderEventProcessor processor;
  private RegionQueue queue;

  @Before
  public void setUp() throws Exception {
    AbstractGatewaySender sender = mock(AbstractGatewaySender.class);
    processor = new ConcurrentSerialGatewaySenderEventProcessor(sender, null);
    queue = mock(RegionQueue.class);
    when(queue.size()).thenReturn(3);
  }

  @Test
  public void eventQueueSizeReturnsSizeOfQueues() {
    processor.getQueues().add(queue);
    assertEquals(3, processor.eventQueueSize());
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/test/java/org/apache/geode/internal/cache/wan/serial/ConcurrentSerialGatewaySenderEventProcessorJUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.wan.serial;

import static org.junit.Assert.assertEquals;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.junit.Before;
import org.junit.Test;

import org.apache.geode.internal.cache.RegionQueue;
import org.apache.geode.internal.cache.wan.AbstractGatewaySender;

public class ConcurrentSerialGatewaySenderEventProcessorJUnitTest {

  private ConcurrentSerialGatewaySenderEventProcessor processor;
  private RegionQueue queue;

  @Before
  public void setUp() throws Exception {
    AbstractGatewaySender sender = mock(AbstractGatewaySender.class);
    processor = new ConcurrentSerialGatewaySenderEventProcessor(sender, null, false);
    queue = mock(RegionQueue.class);
    when(queue.size()).thenReturn(3);
  }

  @Test
  public void eventQueueSizeReturnsSizeOfQueues() {
    processor.getQueues().add(queue);
    assertEquals(3, processor.eventQueueSize());
  }
}
